package com.dgtly.goods.service;

import com.dgtly.common.core.domain.Ztree;
import com.dgtly.goods.domain.GoodsType;
import java.util.List;

/**
 * 商品分类列Service接口
 * 
 * @author dgtly
 * @date 2020-02-13
 */
public interface IGoodsTypeService 
{
    /**
     * 查询商品分类列
     * 
     * @param id 商品分类列ID
     * @return 商品分类列
     */
    public GoodsType selectGoodsTypeById(Long id);

    /**
     * 查询商品分类列列表
     * 
     * @param goodsType 商品分类列
     * @return 商品分类列集合
     */
    public List<GoodsType> selectGoodsTypeList(GoodsType goodsType);

    /**
     * 新增商品分类列
     * 
     * @param goodsType 商品分类列
     * @return 结果
     */
    public int insertGoodsType(GoodsType goodsType);

    /**
     * 修改商品分类列
     * 
     * @param goodsType 商品分类列
     * @return 结果
     */
    public int updateGoodsType(GoodsType goodsType);

    /**
     * 批量删除商品分类列
     * 
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    public int deleteGoodsTypeByIds(String ids);

    /**
     * 删除商品分类列信息
     * 
     * @param id 商品分类列ID
     * @return 结果
     */
    public int deleteGoodsTypeById(Long id);

    /**
     * 获取商品分类树状结构
     * @param goodsType
     * @return
     */
    List<Ztree> selectGoodsTypeTree(GoodsType goodsType);

    /**
     * 根据条件查询查询数量
     * @param goodsType
     * @return
     */
    public Integer selectGoodsTypeCount(GoodsType goodsType);



}
